@@ -24,7 +24,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
-#include <ncurses.h>
+#include <stddef.h>
 #include <errno.h>
 #include <sys/select.h>
 #include <signal.h>
@@ -41,24 +41,41 @@ extern "C" {
 static struct v2_0_config v2_0_config_elements[] = {
 	{"acknowledgement_type",	STATS_OFFSET(acknowledgement_type),	VARTYPE_INT}, 
 	{"active_checks_enabled",	STATS_OFFSET(active_checks_enabled),	VARTYPE_INT}, 
+	{"author",			STATS_OFFSET(author),			VARTYPE_PCHAR},
 	{"check_command",		STATS_OFFSET(check_command),		VARTYPE_PCHAR}, 
 	{"check_execution_time",	STATS_OFFSET(check_execution_time),	VARTYPE_DOUBLE}, 
+	{"check_interval",		STATS_OFFSET(check_interval),		VARTYPE_DOUBLE},
 	{"check_latency",		STATS_OFFSET(check_latency),		VARTYPE_DOUBLE}, 
+	{"check_options",		STATS_OFFSET(check_options),		VARTYPE_INT},
+	{"check_period",		STATS_OFFSET(check_period),		VARTYPE_PCHAR},
 	{"check_type",			STATS_OFFSET(check_type),		VARTYPE_INT}, 
+	{"comment_data",		STATS_OFFSET(comment_data),		VARTYPE_PCHAR},
+	{"comment_id",			STATS_OFFSET(comment_id),		VARTYPE_INT},
 	{"current_attempt",		STATS_OFFSET(current_attempt),		VARTYPE_INT}, 
+	{"current_event_id",		STATS_OFFSET(current_event_id),		VARTYPE_INT},
+	{"current_notification_id",	STATS_OFFSET(current_notification_id),	VARTYPE_INT},
 	{"current_notification_number",	STATS_OFFSET(current_notification_number),	VARTYPE_DOUBLE}, 
+	{"current_problem_id",		STATS_OFFSET(current_problem_id),	VARTYPE_INT},
 	{"current_state",		STATS_OFFSET(current_state),		VARTYPE_INT}, 
+	{"entry_time",			STATS_OFFSET(entry_time),		VARTYPE_TIMET},
+	{"entry_type",			STATS_OFFSET(entry_type),		VARTYPE_INT},
 	{"event_handler",		STATS_OFFSET(event_handler),		VARTYPE_INT}, 
 	{"event_handler_enabled",	STATS_OFFSET(event_handler_enabled),	VARTYPE_INT}, 
+	{"expire_time",			STATS_OFFSET(expire_time),		VARTYPE_TIMET},
+	{"expires",			STATS_OFFSET(expires),			VARTYPE_INT},
 	{"failure_prediction_enabled",	STATS_OFFSET(failure_prediction_enabled),	VARTYPE_INT}, 
 	{"flap_detection_enabled",	STATS_OFFSET(flap_detection_enabled),	VARTYPE_INT}, 
 	{"has_been_checked",		STATS_OFFSET(has_been_checked),		VARTYPE_INT}, 
 	{"host_name",			STATS_OFFSET(host_name),		VARTYPE_PCHAR}, 
+	{"host_notification_period",	STATS_OFFSET(host_notification_period),	VARTYPE_PCHAR},
 	{"is_flapping",			STATS_OFFSET(is_flapping),		VARTYPE_INT}, 
 	{"last_check",			STATS_OFFSET(last_check),		VARTYPE_TIMET}, 
+	{"last_event_id",		STATS_OFFSET(last_event_id),		VARTYPE_INT},
 	{"last_hard_state",		STATS_OFFSET(last_hard_state),		VARTYPE_INT}, 
 	{"last_hard_state_change",	STATS_OFFSET(last_hard_state_change),	VARTYPE_INT}, 
 	{"last_notification",		STATS_OFFSET(last_notification),	VARTYPE_INT}, 
+	{"last_problem_id",		STATS_OFFSET(last_problem_id),		VARTYPE_INT},
+	{"long_plugin_output",		STATS_OFFSET(long_plugin_output),	VARTYPE_PCHAR},
 	{"last_state_change",		STATS_OFFSET(last_state_change),	VARTYPE_TIMET}, 
 	{"last_time_critical",		STATS_OFFSET(last_time_critical),	VARTYPE_INT}, 
 	{"last_time_down",		STATS_OFFSET(last_time_down),		VARTYPE_INT}, 
@@ -68,23 +85,29 @@ static struct v2_0_config v2_0_config_elements[] = {
 	{"last_time_up",		STATS_OFFSET(last_time_up),		VARTYPE_INT}, 
 	{"last_time_warning",		STATS_OFFSET(last_time_warning),	VARTYPE_INT}, 
 	{"last_update",			STATS_OFFSET(last_update),		VARTYPE_TIMET}, 
+	{"long_plugin_output",		STATS_OFFSET(long_plugin_output),	VARTYPE_PCHAR},
 	{"max_attempts",		STATS_OFFSET(max_attempts),		VARTYPE_INT}, 
 	{"modified_attributes",		STATS_OFFSET(modified_attributes),	VARTYPE_INT}, 
 	{"next_check",			STATS_OFFSET(next_check),		VARTYPE_TIMET}, 
+	{"next_comment_id",		STATS_OFFSET(next_comment_id),		VARTYPE_INT},
 	{"next_notification",		STATS_OFFSET(next_notification),	VARTYPE_INT}, 
 	{"no_more_notifications",	STATS_OFFSET(no_more_notifications),	VARTYPE_INT}, 
+	{"notification_period",		STATS_OFFSET(notification_period),	VARTYPE_PCHAR},
 	{"notifications_enabled",	STATS_OFFSET(notifications_enabled),	VARTYPE_INT}, 
 	{"obsess_over_host",		STATS_OFFSET(obsess_over_host),		VARTYPE_INT},
 	{"obsess_over_service",		STATS_OFFSET(obsess_over_service),	VARTYPE_INT}, 
 	{"passive_checks_enabled",	STATS_OFFSET(passive_checks_enabled),	VARTYPE_INT}, 
 	{"percent_state_change",	STATS_OFFSET(percent_state_change),	VARTYPE_DOUBLE}, 
 	{"performance_data",		STATS_OFFSET(performance_data),		VARTYPE_PCHAR}, 
+	{"persistent",			STATS_OFFSET(persistent),		VARTYPE_INT},
 	{"plugin_output",		STATS_OFFSET(plugin_output),		VARTYPE_PCHAR}, 
 	{"problem_has_been_acknowledged",	STATS_OFFSET(problem_has_been_acknowledged),	VARTYPE_INT}, 
 	{"process_performance_data",	STATS_OFFSET(process_performance_data),	VARTYPE_INT}, 
+	{"retry_interval",		STATS_OFFSET(retry_interval),		VARTYPE_DOUBLE},
 	{"scheduled_downtime_depth",	STATS_OFFSET(scheduled_downtime_depth),	VARTYPE_DOUBLE}, 
 	{"service_description",		STATS_OFFSET(service_description),	VARTYPE_PCHAR}, 
 	{"should_be_scheduled",		STATS_OFFSET(should_be_scheduled),	VARTYPE_INT}, 
+	{"source",			STATS_OFFSET(source),			VARTYPE_INT},
 	{"state_type",			STATS_OFFSET(state_type),		VARTYPE_INT}, 
 	{"type",			STATS_OFFSET(type),			VARTYPE_INT}
 };
@@ -234,9 +257,14 @@ void parse_2_0_statuslog(int fd, struct stats **pstats, int *n_stats)
 				*pstats = (struct stats *)myrealloc(*pstats, n_alloc * sizeof(struct stats), "stats array");
 				if (!*pstats)
 					error_exit("Error allocating memory");
+
+				memset(&(*pstats)[*n_stats], 0x00, sizeof(struct stats) * (n_alloc - *n_stats));
+			}
+			else
+			{
+				memset(&(*pstats)[*n_stats], 0x00, sizeof(struct stats));
 			}
 
-			memset(&(*pstats)[*n_stats], 0x00, sizeof(struct stats));
 
 			if (strncmp(line, "host ", 5) == 0)
 			{
@@ -675,7 +703,7 @@ int host_is_down(struct stats *pstats, int n_stats, char *host_name)
 		if (pstats[loop].current_state == 1 || // down
 				pstats[loop].current_state == 2) // unreachable
 		{
-			if (strcmp(pstats[loop].host_name, host_name) == 0)
+			if (pstats[loop].host_name != NULL && strcmp(pstats[loop].host_name, host_name) == 0)
 				return loop;
 		}
 	}
@@ -726,8 +754,8 @@ int find_index_by_host_and_service(struct stats *pstats, int n_stats, char *host
 		for(loop=0; loop<n_stats; loop++)
 		{
 			int index = (last + loop) % n_stats;
-			if (strcmp(pstats[index].host_name, host_name) == 0 &&
-					strcmp(pstats[index].service_description, service_description) == 0)
+			if (pstats[index].host_name != NULL && strcmp(pstats[index].host_name, host_name) == 0 &&
+					pstats[index].service_description != NULL && strcmp(pstats[index].service_description, service_description) == 0)
 			{
 				last = index;
 				return index;
@@ -739,7 +767,7 @@ int find_index_by_host_and_service(struct stats *pstats, int n_stats, char *host
 		for(loop=0; loop<n_stats; loop++)
 		{
 			int index = (last + loop) % n_stats;
-			if (pstats[index].service_description == NULL && strcmp(pstats[index].host_name, host_name) == 0)
+			if (pstats[index].service_description == NULL && pstats[index].host_name != NULL && strcmp(pstats[index].host_name, host_name) == 0)
 			{
 				last = index;
 				return index;
@@ -807,8 +835,8 @@ int check_max_age_last_check(struct stats *pstats, int n_stats, int max_time_las
 			{
 				most_recent_host_check = max(most_recent_host_check, pstats[index].last_check);
 
-//				if (check_an_age(message, "oldest host check", now, pstats[index].last_check, max_time_oldest_host_check, pstats[index].host_name) == -1)
-//					return -1;
+				//				if (check_an_age(message, "oldest host check", now, pstats[index].last_check, max_time_oldest_host_check, pstats[index].host_name) == -1)
+				//					return -1;
 			}
 		}
 		else if (pstats[index].type == TYPE_SERVICE)
@@ -835,8 +863,8 @@ int check_max_age_last_check(struct stats *pstats, int n_stats, int max_time_las
 	if (check_an_age(message, "most recent host update", now, most_recent_host_update, max_time_last_host_update, NULL) == -1)
 		return -1;
 
-//	if (check_an_age(message, "most recent host check", now, most_recent_host_check, max_time_last_host_check, NULL) == -1)
-//		return -1;
+	//	if (check_an_age(message, "most recent host check", now, most_recent_host_check, max_time_last_host_check, NULL) == -1)
+	//		return -1;
 
 	if (check_an_age(message, "most recent last service check", now, most_recent_last_service_check, max_time_last_service_check, NULL) == -1)
 		return -1;
@@ -854,30 +882,27 @@ void calc_stats_stats(struct stats *pstats, int n_stats, char list_all_problems,
 
 	for(int loop=0; loop<n_stats; loop++)
 	{
-		if (should_i_show_entry(pstats, n_stats, loop, list_all_problems, always_notify, also_acknowledged, hide_ok))
+		if (pstats[loop].type == TYPE_HOST)
 		{
-			if (pstats[loop].type == TYPE_HOST)
-			{
-				if (pstats[loop].current_state == 0)
-					(*n_up)++;
-				else if (pstats[loop].current_state == 1)
-					(*n_down)++;
-				else if (pstats[loop].current_state == 2)
-					(*n_unreachable)++;
-				else if (pstats[loop].current_state == 3)
-					(*n_pending)++;
-			}
-			else if (pstats[loop].type == TYPE_SERVICE)
-			{
-				if (pstats[loop].current_state == 0)
-					(*n_ok)++;
-				else if (pstats[loop].current_state == 1)
-					(*n_warning)++;
-				else if (pstats[loop].current_state == 2)
-					(*n_critical)++;
-			}
-			else
-				error_exit("calc_stats_stats: internal error (%d)", pstats[loop].type);
+			if (pstats[loop].current_state == 0)
+				(*n_up)++;
+			else if (pstats[loop].current_state == 1)
+				(*n_down)++;
+			else if (pstats[loop].current_state == 2)
+				(*n_unreachable)++;
+			else if (pstats[loop].current_state == 3)
+				(*n_pending)++;
 		}
+		else if (pstats[loop].type == TYPE_SERVICE)
+		{
+			if (pstats[loop].current_state == 0)
+				(*n_ok)++;
+			else if (pstats[loop].current_state == 1)
+				(*n_warning)++;
+			else if (pstats[loop].current_state == 2)
+				(*n_critical)++;
+		}
+		else
+			error_exit("calc_stats_stats: internal error (%d)", pstats[loop].type);
 	}
 }
